SystemOrganization addCategory: #ConfigurationOfXMLPullParser!

Object subclass: #ConfigurationOfXMLPullParser
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfXMLPullParser'!

!ConfigurationOfXMLPullParser class methodsFor: 'development support' stamp: 'HernanMoralesDurand 8/14/2013 08:29'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfXMLPullParser class methodsFor: 'private' stamp: 'HernanMoralesDurand 8/14/2013 08:29'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfXMLPullParser class methodsFor: 'catalog' stamp: 'HernanMoralesDurand 10/1/2013 03:16'!
catalogChangeLog
		
 ^ '- Version 1.0 migrated to SmalltalkHub
[[[
(ConfigurationOfXMLPullParser project version: ''1.0'') load
]]]
'
	
	! !

!ConfigurationOfXMLPullParser class methodsFor: 'catalog' stamp: 'HernanMoralesDurand 10/1/2013 02:48'!
catalogDescription

	^ 'XMLPullParser is a streaming XML parser (StAX parsing). Instead of building a DOM tree, the parser streams over "events" (start tag, text, end tag) on demand. It allows processing custom tokens (skipping forward) and is suitable for streaming applications (very large documents). The parser doesn''t creates long-lived objects. For more information on the technique in general, see xmlpull.org.
	
This implementation is a mashup of Antony Blakey''s XMLPullParser (for VisualWorks, which makes use of the VisualWorks XML code) and the Squeak XMLTokenizer.'! !

!ConfigurationOfXMLPullParser class methodsFor: 'catalog' stamp: 'HernanMoralesDurand 10/1/2013 03:10'!
catalogKeyClassesAndExample

	^ ' ==XMLPullParser== is the main public class of the package. It is the class to interact with as shown by the tests. 

The ==XPPEvent== hierarchy holds the five kinds of events/tokens that the parser produces: {Start/End}Document, {Start/End}Tag, and Text. 

The following is an example of parsing and printing text contents from a XML from a document found in the web:
[[[ 
| xmlStream |
xmlStream := ''http://www.w3schools.com/xml/simple.xml'' asUrl retrieveContents readStream.	
[ | xpp output |
	output := String new writeStream.
	xpp := XMLPullParser parse: xmlStream.
	[ xpp next isEndDocument ] whileFalse: [
		xpp isText ifTrue: [ output nextPutAll: xpp text; cr ] ].
	^ output contents.
] ensure: [ xmlStream close ].
]]]

The package contains SUnit tests in the XMLPullParserTest class.'! !

!ConfigurationOfXMLPullParser class methodsFor: 'catalog' stamp: 'HernanMoralesDurand 10/1/2013 03:11'!
catalogKeywords
	^ #(XML web query parsing StAX streaming)
	! !

!ConfigurationOfXMLPullParser class methodsFor: 'private' stamp: 'HernanMoralesDurand 8/14/2013 08:29'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfXMLPullParser class methodsFor: 'private' stamp: 'HernanMoralesDurand 8/14/2013 08:29'!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfXMLPullParser class methodsFor: 'metacello tool support' stamp: 'HernanMoralesDurand 8/14/2013 08:29'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfXMLPullParser class methodsFor: 'loading' stamp: 'HernanMoralesDurand 8/14/2013 08:29'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfXMLPullParser class methodsFor: 'loading' stamp: 'HernanMoralesDurand 8/14/2013 08:29'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfXMLPullParser class methodsFor: 'loading' stamp: 'HernanMoralesDurand 8/14/2013 08:29'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfXMLPullParser class methodsFor: 'accessing' stamp: 'HernanMoralesDurand 8/14/2013 08:29'!
project

	^self new project! !

!ConfigurationOfXMLPullParser class methodsFor: 'development support' stamp: 'HernanMoralesDurand 8/14/2013 08:29'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfXMLPullParser methodsFor: 'baselines' stamp: 'HernanMoralesDurand 8/14/2013 08:29'!
baseline10: spec
	<version: '1.0-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://www.smalltalkhub.com/mc/hernan/XMLPullParser/main'.
		spec package: 'XMLPullParser'.
		spec group: 'default' with: #('XMLPullParser' ). ].
! !

!ConfigurationOfXMLPullParser methodsFor: 'accessing' stamp: 'HernanMoralesDurand 8/14/2013 08:29'!
customProjectAttributes
	 "Edit to return a collection of any custom attributes e.g. for conditional loading: Array with: #'Condition1' with: #'Condition2.
	For more information see: http://code.google.com/p/metacello/wiki/CustomProjectAttrributes"

	^ #().! !

!ConfigurationOfXMLPullParser methodsFor: 'symbolic versions' stamp: 'HernanMoralesDurand 8/14/2013 08:30'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: '1.0'.
! !

!ConfigurationOfXMLPullParser methodsFor: 'accessing' stamp: 'HernanMoralesDurand 8/14/2013 08:29'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		project := MetacelloMCProject new projectAttributes: self customProjectAttributes. 
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self project: project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfXMLPullParser methodsFor: 'symbolic versions' stamp: 'HernanMoralesDurand 8/14/2013 08:30'!
stable: spec
	<symbolicVersion: #'stable'>

	spec for: #'common' version: '1.0'.
! !

!ConfigurationOfXMLPullParser methodsFor: 'versions' stamp: 'HernanMoralesDurand 8/14/2013 08:30'!
version10: spec
	<version: '1.0' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: ''.
		spec author: 'HernanMoralesDurand'.
		spec timestamp: '8/14/2013 08:29'.
		spec package: 'XMLPullParser' with: 'XMLPullParser-HernanMoralesDurand.13'. ].
! !
